@@ -4,6 +4,7 @@ import collections
 import copy
 from django.core.exceptions import ImproperlyConfigured
 from django.conf import global_settings
+from django.utils.module_loading import module_has_submodule
 import importlib
 import operator
 
@@ -73,7 +74,7 @@ class OrderingRelationship(object):
 
         return changes
 
-def merge_dictionaries(current, new):
+def merge_dictionaries(current, new, only_defaults=False):
     '''
     Merge two settings dictionaries, recording how many changes were needed.
 
@@ -87,6 +88,8 @@ def merge_dictionaries(current, new):
                 current[key] = copy.deepcopy(value)
                 changes += 1
                 continue
+        elif only_defaults:
+            continue
         current_value = current[key]
         if hasattr(current_value, 'items'):
             changes += merge_dictionaries(current_value, value)
@@ -115,11 +118,22 @@ def configure_settings(settings):
     while changes or old_changes is None:
         changes = 0
         for app_name in settings['INSTALLED_APPS']:
-            try:
-                module = importlib.import_module("%s.autoconfig" % (app_name,))
-            except ImportError:
+            if app_name in settings.get('AUTOCONFIG_DISABLED_APPS', ()):
+                # This app is disabled, skip it
                 continue
-            changes += merge_dictionaries(settings, getattr(module, 'SETTINGS', {}))
+            app_module = importlib.import_module(app_name)
+            if not module_has_submodule(app_module, 'autoconfig'):
+                continue
+            module = importlib.import_module("%s.autoconfig" % (app_name,))
+            changes += merge_dictionaries(
+                settings,
+                getattr(module, 'SETTINGS', {}),
+            )
+            changes += merge_dictionaries(
+                settings,
+                getattr(module, 'DEFAULT_SETTINGS', {}),
+                only_defaults=True,
+            )
             for relationship in getattr(module, 'RELATIONSHIPS', []):
                 changes += relationship.apply_changes(settings)
         num_apps = len(settings['INSTALLED_APPS'])
